bayespy.inference.vmp.nodes.node.Node.broadcasting_multiplier
=============================================================

.. currentmodule:: bayespy.inference.vmp.nodes.node

.. automethod:: Node.broadcasting_multiplier